@@ -339,8 +339,9 @@ class tabledata(object):
         self._columns.remove(c)
 
     def rename(self, c_old, c_new):
-        setattr(self, c_new, getattr(self, c_old))
+        val = getattr(self, c_old)
         self.delete_column(c_old)
+        setattr(self, c_new, val)
         
     def __setitem__(self, I, O):
 
@@ -1021,6 +1022,8 @@ def text_table_fields(forfn, text=None, skiplines=0, split=None, trycsv=True, ma
                         cd.append(np.nan)
                         continue
                     c = floatvalmap.get(c, c)
+                    # strip stray spaces or commas from float values
+                    c = c.strip(', ')
 
                 if t in [int, np.int32, np.int64]:
                     try:
